"""Add font files to the matplotlib font manager.

If adding new fonts, copy from
https://matplotlib.org/stable/users/explain/customizing.html#the-default-matplotlibrc-file
and keep only the settings that are different from the default.
"""

import pathlib

from matplotlib import font_manager


def _add_fonts() -> None:
    """Add font files to the matplotlib font manager."""
    fonts_module_dir = pathlib.Path(__file__).parent
    font_files = font_manager.findSystemFonts(fontpaths=[fonts_module_dir])

    for font_file in font_files:
        font_manager.fontManager.addfont(font_file)


__all__ = ["_add_fonts"]



import re
import unicodedata
from pathlib import Path
from glob import glob
import click


def sort_pdfs_by_mi(fn: str):
    """Key for sorted() to sort filenames by leading number.
    The number must be separated with '-'.
    """
    try:
        return float(Path(fn).stem.split("-")[0])
    except ValueError:
        return -1


def slugify(value, allow_unicode=False):
    """
    Convert to ASCII if 'allow_unicode' is False. Convert spaces or repeated
    dashes to single dashes. Remove characters that aren't alphanumerics,
    underscores, or hyphens. Convert to lowercase. Also strip leading and
    trailing whitespace, dashes, and underscores.
    Source: https://github.com/django/django/blob/0b78ac3fc7bd9f0c57518d0c1a153582318edd59/django/utils/text.py#L420.
    """
    value = str(value)
    if allow_unicode:
        value = unicodedata.normalize("NFKC", value)
    else:
        value = (
            unicodedata.normalize("NFKD", value)
            .encode("ascii", "ignore")
            .decode("ascii")
        )
    value = re.sub(r"[^\w\s-]", "", value.lower())
    return re.sub(r"[-\s]+", "-", value).strip("-_")


def verify_input_dir(input_dir: Path):
    while True:
        if input_dir.exists():
            break
        input_dir = Path(
            input(
                f"Input directory {input_dir} does not exist. "
                "Please specify an existing input directory.\n"
            )
        )

    output_dir = input_dir / "outputs"
    print(f"Reading files from {input_dir}.")
    print(f"Output files in {output_dir}.")

    input_paths = list(glob(f"{input_dir / '*.xlsx'}")) + list(
        glob(f"{input_dir / '*.csv'}")
    )
    input_paths_num = len(input_paths)
    if not input_paths_num:
        print(f"Please provide an input file (.csv or .xlsx) in {input_dir}.")
        exit(1)
    elif input_paths_num > 1:
        while True:
            print("\nMore than one input file found.")
            for i, input_path in enumerate(input_paths, 1):
                print(f"[{i}] {input_path}")
            try:
                input_index = int(click.getchar())
                input_path = Path(input_paths[input_index - 1])
            except (ValueError, IndexError):
                continue
            else:
                break

    else:
        input_path = Path(input_paths[0])

    return input_path, output_dir



import sys
from pathlib import Path

import streamlit as st
import tkinter as tk
from tkinter import filedialog

sys.path.append(str(Path(__file__).absolute().parent.parent))

from ithappens.create_cards import main, parse_input_file


def select_folder():
    root = tk.Tk()
    root.withdraw()
    folder_path = filedialog.askdirectory(parent=root)
    root.destroy()
    return Path(folder_path)


with st.sidebar:
    st.title("It Happens")
    st.write("Create your own Shit Happens playing cards!")
    st.write(
        "Ever wanted to play with your own [Shit Happens](https://boardgamegeek.com/boardgame/196379/shit-happens) playing cards? Now you can. Write down the most miserable situations you can think of and rank them. This project automatically outputs playing cards in pdf format."
    )
    st.write(
        "This project is not related to the original card game. [Open an issue](https://github.com/siemdejong/ithappens/issues/new/choose) in case of any objections."
    )
    st.write(
        '<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">This project is open source.<br>See <a href=https://github.com/siemdejong/ithappens><i class="fa-brands fa-github">&nbsp;</i>siemdejong/ithappens</a>.',
        unsafe_allow_html=True,
    )
    st.components.v1.html(
        '<br><script type="text/javascript" src="https://cdnjs.buymeacoffee.com/1.0.0/button.prod.min.js" data-name="bmc-button" data-slug="siemdejong" data-color="#FFDD00" data-emoji="🍺"  data-font="Lato" data-text="Buy me a beer" data-outline-color="#000000" data-font-color="#000000" data-coffee-color="#ffffff" ></script>'
    )

uploaded_file = st.file_uploader("Please provide your excel or csv input file")

if uploaded_file is not None:
    df = parse_input_file(uploaded_file)
    expansion_name = st.text_input("Expansion name")
    input_dir = st.session_state.get("input_dir", None)
    folder_select_button = st.button("Select input directory")
    if folder_select_button:
        input_dir = select_folder()
        st.session_state.input_dir = input_dir
    if input_dir:
        st.write("Selected input directory path:", input_dir)
        output_dir = input_dir / "outputs"

    merge = st.checkbox("Merge output", value=True)
    side = st.selectbox("Side(s) to generate", ["both", "front", "back"])
    format = st.selectbox("Output format", ["pdf", "png"])
    workers = st.number_input("Number of workers", value=4)
    chunks = st.number_input("Number of chunks for the workers to process", value=30)

    if st.button("Create cards"):
        main(
            name=expansion_name,
            input_dir=input_dir,
            merge=merge,
            side=side,
            format=format,
            workers=workers,
            chunks=chunks,
        )
        st.write("Cards written to ", output_dir)



import os
import matplotlib.pyplot as plt
import ithappens


def _register():
    # register the bundled stylesheets in the matplotlib style library
    ithappens_path = ithappens.__path__[0]
    styles_path = os.path.join(ithappens_path, "style", "styles")

    # Reads styles in /styles folder and all subfolders
    stylesheets = {}  # plt.style.library is a dictionary
    for folder, _, _ in os.walk(styles_path):
        new_stylesheets = plt.style.core.read_style_directory(folder)
        stylesheets.update(new_stylesheets)

    # Update dictionary of styles - plt.style.library
    plt.style.core.update_nested_dict(plt.style.library, stylesheets)
    # Update `plt.style.available`, copy-paste from:
    # https://github.com/matplotlib/matplotlib/blob/a170539a421623bb2967a45a24bb7926e2feb542/lib/matplotlib/style/core.py#L266  # noqa: E501
    plt.style.core.available[:] = sorted(plt.style.library.keys())


__all__ = ["_register"]



"""It Happens

A Python package for creating your own Shit Happens playing cards.
"""

from ithappens.style.styles.registration import _register
from ithappens.style.fonts.manage import _add_fonts

_add_fonts()
_register()
